# Generated by Django 4.1.7 on 2023-05-18 08:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('capeditor', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='alertinfo',
            name='language',
            field=models.CharField(blank=True, choices=[('en', 'English'), ('fr', 'French'), ('ar', 'Arabic'), ('am', 'Amharic'), ('sw', 'Swahili')], default='en', help_text='The code denoting the language of the alert message', max_length=100, null=True, verbose_name='Language'),
        ),
    ]
