# Generated by Django 4.1.7 on 2023-06-19 12:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('capeditor', '0002_alter_alertinfo_language'),
    ]

    operations = [
        migrations.AlterField(
            model_name='alert',
            name='sender',
            field=models.EmailField(help_text=' Identifies the originator of an alert. This can be an email of the institution for example', max_length=255, verbose_name='Sender'),
        ),
    ]
